==> jside-0.0.2.tgz: package/main.js <==
let electron=require("electron")
const app = electron.app;
let windows={}
const BrowserWindow = electron.BrowserWindow;
let io=require('socket.io-client');
let socket=io('ws://127.0.0.1:'+process.argv[2])

function createWindow (cfg) {
let  BrWindow = new BrowserWindow({
    width: cfg.w,
    height: cfg.h,
    fullscreen:cfg.fullscreen,
    frame:cfg.windowManager,
    resizable:cfg.resizable,
    webPreferences: {
        nodeIntegration: true
    }
    });



return BrWindow

}

socket.on("newWindow",(cfg,wid)=>{
  if(typeof cfg!=="object"||cfg==undefined){cfg={}}
  if(!cfg.w){cfg.w=500}
  if(!cfg.h){cfg.h=500}
  if(!cfg.fullscreen){cfg.fullscreen=false}
  if(!cfg.windowManager){cfg.windowManager=true}
  if(!cfg.resizable){cfg.resizable=false}
windows[wid]=createWindow(cfg)


windows[wid].loadURL("file://"+__dirname+"/main.html")
windows[wid].webContents.executeJavaScript("let socket=connect("+JSON.stringify({port:process.argv[2],wid:wid})+")")
windows[wid].webContents.executeJavaScript(`
  socket.on("execJS",(code)=>{
    eval("code")
  })`)


windows[wid].on("resize",(data)=>{

  socket.emit("windowResize",{wid:wid,data:{
    w:windows[wid].webContents.getOwnerBrowserWindow().getBounds().width
    ,h:windows[wid].webContents.getOwnerBrowserWindow().getBounds().height
  }})
})
})
socket.on("windowExec",(params)=>{
  wid=params.wid
  code=params.code
  windows[wid].webContents.executeJavaScript(code)
})
socket.on("disconnect",()=>{app.quit();process.exit()})
app.on('window-all-closed', function () {
  if (process.platform !== 'darwin') {
    socket.emit("all-windows-closed")
  }
});

==> jside-0.0.3.tgz: package/main.js <==
let electron=require("electron")
const app = electron.app;
let windows={}
const BrowserWindow = electron.BrowserWindow;
let io=require('socket.io-client');
let socket=io('ws://127.0.0.1:'+process.argv[2])

function createWindow (cfg) {
let  BrWindow = new BrowserWindow({
    width: cfg.w,
    height: cfg.h,
    fullscreen:cfg.fullscreen,
    frame:cfg.windowManager,
    resizable:cfg.resizable,
    webPreferences: {
        nodeIntegration: true
    }
    });



return BrWindow

}

socket.on("newWindow",(cfg,wid)=>{
  if(typeof cfg!=="object"||cfg==undefined){cfg={}}
  if(!cfg.w){cfg.w=500}
  if(!cfg.h){cfg.h=500}
  if(!cfg.fullscreen){cfg.fullscreen=false}
  if(!cfg.windowManager){cfg.windowManager=true}
  if(!cfg.resizable){cfg.resizable=false}
windows[wid]=createWindow(cfg)


windows[wid].loadURL("file://"+__dirname+"/main.html")
console.log(windows[wid].webContents.executeJavaScript("let socket=connect("+JSON.stringify({port:process.argv[2],wid:wid})+")"))
windows[wid].webContents.executeJavaScript(`
  socket.on("execJS",(code)=>{
    eval("code")
  })`)


windows[wid].on("resize",(data)=>{

  socket.emit("windowResize",{wid:wid,data:{
    w:windows[wid].webContents.getOwnerBrowserWindow().getBounds().width
    ,h:windows[wid].webContents.getOwnerBrowserWindow().getBounds().height
  }})
})
})
socket.on("windowExec",(params)=>{
  rid=params.rid
  wid=params.wid
  code=params.code
  windows[wid].webContents.executeJavaScript(code).then((res)=>{socket.emit("execResult",{rid:rid,data:res})})
})
socket.on("disconnect",()=>{app.quit();process.exit()})
app.on('window-all-closed', function () {
  if (process.platform !== 'darwin') {
    socket.emit("all-windows-closed")
  }
});
